==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/eu.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Eskaera tokenen eskuratzeak huts egin du. Egiaztatu zure Dropbox app giltza eta sekretua zuzenak direla.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Sarrera tokenen eskuratzeak huts egin du. Egiaztatu zure Dropbox app giltza eta sekretua zuzenak direla.",
    "Please provide a valid Dropbox app key and secret." : "Mesedez eman baliozkoa den Dropbox app giltza eta sekretua",
    "Step 1 failed. Exception: %s" : "1 Urratsak huts egin du. Salbuespena: %s",
    "Step 2 failed. Exception: %s" : "2 Urratsak huts egin du. Salbuespena: %s",
    "External storage" : "Kanpoko biltegiratzea",
    "Local" : "Bertakoa",
    "Location" : "Kokapena",
    "Amazon S3" : "Amazon S3",
    "Key" : "Gakoa",
    "Secret" : "Sekretua",
    "Amazon S3 and compliant" : "Amazon S3 eta baliokideak",
    "Access Key" : "Sarbide gakoa",
    "Secret Key" : "Giltza Sekretua",
    "Hostname" : "Ostalari izena",
    "Port" : "Portua",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu Bide Estiloa",
    "App key" : "Aplikazio gakoa",
    "App secret" : "App sekretua",
    "Host" : "Ostalaria",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure ftps://" : "ftps:// segurua",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren Sekretua",
    "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
    "Region (optional for OpenStack Object Storage)" : "Eskualdea (hautazkoa OpenStack Objektu Biltegiratzerako)",
    "API Key (required for Rackspace Cloud Files)" : "API Giltza (beharrezkoa Rackspace Cloud Filesentzako)",
    "Tenantname (required for OpenStack Object Storage)" : "Tenantname (beharrezkoa OpenStack Objektu Biltegiratzerko)",
    "Password (required for OpenStack Object Storage)" : "Pasahitza (beharrezkoa OpenStack Objektu Biltegiratzerako)",
    "Service Name (required for OpenStack Object Storage)" : "Zerbitzuaren Izena (beharrezkoa OpenStack Objektu Biltegiratzerako)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "Nortasun amaierako puntuaren URLa (beharrezkoa OpenStack Objektu Biltegiratzerako)",
    "Timeout of HTTP requests in seconds" : "HTTP eskarien gehienezko denbora segundutan",
    "Share" : "Partekatu",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
    "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
    "URL" : "URL",
    "Secure https://" : "https:// segurua",
    "Public key" : "Gako publikoa",
    "Access granted" : "Sarrera baimendua",
    "Error configuring Dropbox storage" : "Errore bat egon da Dropbox biltegiratzea konfiguratzean",
    "Grant access" : "Baimendu sarrera",
    "Error configuring Google Drive storage" : "Errore bat egon da Google Drive konfiguratzean",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(group)" : "(taldea)",
    "Saved" : "Gordeta",
    "<b>Note:</b> " : "<b>Oharra:</b>",
    "and" : "eta",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko cURL euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko FTP euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b>\"%s\" euskarria ez dago instalatuta Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "No external storage configured" : "Ez da kanpo biltegiratzerik konfiguratu",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "External Storage" : "Kanpoko biltegiratzea",
    "Folder name" : "Karpetaren izena",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Add storage" : "Gehitu biltegiratzea",
    "Delete" : "Ezabatu",
    "Enable User External Storage" : "Gaitu erabiltzaileentzako kanpo biltegiratzea",
    "Allow users to mount the following external storage" : "Baimendu erabiltzaileak hurrengo kanpo biltegiratzeak muntatzen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/eu.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1 Urratsak huts egin du. Salbuespena: %s",
    "Step 2 failed. Exception: %s" : "2 Urratsak huts egin du. Salbuespena: %s",
    "External storage" : "Kanpoko biltegiratzea",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Grant access" : "Baimendu sarrera",
    "Access granted" : "Sarrera baimendua",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(group)" : "(taldea)",
    "Saved" : "Gordeta",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Save" : "Gorde",
    "None" : "Ezer",
    "App key" : "Aplikazio gakoa",
    "App secret" : "App sekretua",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren Sekretua",
    "API key" : "APIaren gakoa",
    "Public key" : "Gako publikoa",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Ostalari izena",
    "Port" : "Portua",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu Bide Estiloa",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure https://" : "https:// segurua",
    "Dropbox" : "Dropbox",
    "Host" : "Ostalaria",
    "Secure ftps://" : "ftps:// segurua",
    "Local" : "Bertakoa",
    "Location" : "Kokapena",
    "ownCloud" : "ownCloud",
    "Root" : "Erroa",
    "Share" : "Partekatu",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
    "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
    "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
    "<b>Note:</b> " : "<b>Oharra:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko cURL euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko FTP euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b>\"%s\" euskarria ez dago instalatuta Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "No external storage configured" : "Ez da kanpo biltegiratzerik konfiguratu",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "External Storage" : "Kanpoko biltegiratzea",
    "Folder name" : "Karpetaren izena",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Add storage" : "Gehitu biltegiratzea",
    "Delete" : "Ezabatu",
    "Allow users to mount the following external storage" : "Baimendu erabiltzaileak hurrengo kanpo biltegiratzeak muntatzen",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko FTP euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz"
},
"nplurals=2; plural=(n != 1);");
